# caio/__init__.py

# This allows developers to use: from caio import CAIO
from .optimizer import CAIO

# You can also define the version here for easier tracking
__version__ = "0.1.0"
__author__ = "Atharva Matale"