from setuptools import setup, find_packages

setup(
    name="caio-atharva",           # Your new unique project name
    version="1.0.2",                # Bumped version for the new name
    packages=find_packages(),
    author="Atharva Matale",        # Your official credit
    description="Cost-Aware Inference Orchestration - Hardcore Minifier by Atharva",
    long_description=open("README.md").read() if hasattr(open("README.md"), 'read') else "CAIO Hardcore AI optimizer.",
    long_description_content_type="text/markdown",
    install_requires=[],            # Zero dependencies for maximum speed
    python_requires='>=3.7',
)